def print_u(the_list):
    for each_item in the_list:
        if isinstance(each_item, list):
            print_u(each_item)
        else:
            print(each_item)


def addition(a, b):
    return a + b



from distutils.core import setup

setup(
    name = 'tester_mine',
    version = '1.0.0',
    py_modules = ['nester_mine'],
    author = 'Neeta',
    author_email = 'neeta.kc104@gmail.com',
    description = 'module to print nested list'
)